@@ -263,22 +263,24 @@ int calculate_offset_of_day(int count_day){
 		offset;
     time_t	current_day,
 		current_time,
-		utc_time,
 		date_time;
     struct tm	*tm = NULL;
     double	pre_offset = 0.0F;
     gchar	date_in_string[255];
+    
 
 /* get current day */  
     current_time = time(NULL);
-    utc_time = mktime(gmtime(&current_time));
-    diff_time = utc_time - current_time + 60 * 60 * atol(item_value(wcs.day_data[0], "station_time_zone"));
+
+    diff_time = calculate_diff_time(atol(item_value(wcs.day_data[0], "station_time_zone")));
+
     current_time += diff_time;
     current_day = current_time;
     tm = localtime(&current_day);
     year = 1900 + tm->tm_year;
     current_month = tm->tm_mon;
     tm->tm_sec = 0; tm->tm_min = 0; tm->tm_hour = 0;
+    tm->tm_isdst = 1;
     current_day = mktime(tm);
 
     memset(date_in_string, 0, sizeof(date_in_string));
@@ -293,11 +295,11 @@ int calculate_offset_of_day(int count_day){
 	strptime(date_in_string, "%b %d %Y %T", tm);
     }
     date_time = mktime(tm);
+
     /* calculate days offset */
     pre_offset = (double)(abs(current_day - date_time));
     pre_offset /= 24.0F * 60.0F * 60.0F;
     offset = (int)( round(pre_offset) );
-
     if(offset >= Max_count_weather_day || count_day < 0)
 	offset = Max_count_weather_day;
     
@@ -319,12 +321,11 @@ void weather_buttons_fill(gboolean check_error){
 		date_in_string[255];
     time_t	current_time,
     		current_day,
-		utc_time,
 		last_day = 0,
 		date_time,
 		day_begin_time,
-		night_begin_time;
-    struct tm	*tm = NULL,
+		night_begin_time;		
+    struct tm	*tm = NULL, 
 		tmp_tm;
     gboolean	flag_last_day = FALSE,
 		error_station_code = FALSE;
@@ -386,14 +387,16 @@ void weather_buttons_fill(gboolean check_error){
     remove_daytime_event();
 /* get current day */  
     current_time = time(NULL);
-    utc_time = mktime(gmtime(&current_time));
-    diff_time = utc_time - current_time + 60 * 60 * atol(item_value(wcs.day_data[0], "station_time_zone"));
+
+    diff_time = calculate_diff_time(atol(item_value(wcs.day_data[0], "station_time_zone")));
+    
     current_time += diff_time;
     current_day = current_time;
     tm = localtime(&current_day);
     year = 1900 + tm->tm_year;
     current_month = tm->tm_mon;
     tm->tm_sec = 0; tm->tm_min = 0; tm->tm_hour = 0;
+    tm->tm_isdst = 1;
     current_day = mktime(tm);
 
     offset = calculate_offset_of_day(count_day);
@@ -468,11 +471,13 @@ void weather_buttons_fill(gboolean check_error){
             	    time_event_add(night_begin_time - diff_time, DAYTIMEEVENT);
 		
 		#ifndef RELEASE
-		fprintf(stderr, "\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
+		fprintf(stderr, "\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
 		fprintf(stderr, "Zone time %s", ctime(&current_time));
 		tmp_time = last_update_time(wcs.current_data);
 		fprintf(stderr, "Last update: %s", ctime(&tmp_time));
 		fprintf(stderr, "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n");
+		fprintf(stderr, "Current time: %s", ctime(&current_time));
+		fprintf(stderr, "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n");
 		#endif
 		/* check weather data for actuality */
 		if( !wcs.current_data_is_invalid && 
@@ -553,7 +558,7 @@ void weather_buttons_fill(gboolean check_error){
 			/* The string of forecast for Combination mode */
 			if((current_time > day_begin_time) && (current_time < night_begin_time)){
 			        memset(app->forecast_string, 0, sizeof(app->forecast_string));
-				strcat(app->forecast_string, item_value(wcs.day_data[i + j], "day_title"));
+				strcat(app->forecast_string, (char*)hash_table_find(item_value(wcs.day_data[i + j], "day_title")));
 				strcat(app->forecast_string, _("\nHumidity: "));
 				if(strcmp(item_value(wcs.day_data[i + j], "day_humidity"), "N/A"))
 				    sprintf(app->forecast_string + strlen(app->forecast_string), "%s%%\n",
@@ -851,6 +856,10 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
 	/* disconnected from HildonHomeArea expose-event */
 	g_signal_handler_disconnect(app->parent_parent,app->signal_area_expose);
         g_signal_handler_disconnect(app->top_widget,app->signal_expose);
+        if(app->pixbuf){ 
+	    gdk_pixbuf_unref(app->pixbuf);
+	    app->pixbuf = NULL; 
+	}
     #endif	
 			
     osso = (osso_context_t*)applet_data;
@@ -862,23 +871,23 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
     	    g_free(app->config);
 	if(app->countrys_list){
 	    gtk_list_store_clear(app->countrys_list);
-	    app->countrys_list = NULL;
+	    g_object_unref(app->countrys_list);
 	}
 	if(app->regions_list){
 	    gtk_list_store_clear(app->regions_list);
-	    app->regions_list = NULL;
+	    g_object_unref(app->regions_list);
 	}
 	if(app->stations_list){
 	    gtk_list_store_clear(app->stations_list);
-	    app->stations_list = NULL;
+	    g_object_unref(app->stations_list);
 	}
 	if(app->time_update_list){
 	    gtk_list_store_clear(app->time_update_list);
-	    app->time_update_list = NULL;
+	    g_object_unref(app->time_update_list);
 	}
 	if(app->user_stations_list){
 	    gtk_list_store_clear(app->user_stations_list);
-	    app->user_stations_list = NULL;
+	    g_object_unref(app->user_stations_list);
 	}
     }
     app && (g_free(app), app = NULL);
@@ -1137,8 +1146,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
 		*station_name = NULL,
 		*station_box = NULL;
     time_t	current_time,
-                diff_time,
-                utc_time;
+                diff_time;
     int		n, elements, x, y;
     GtkTreeIter	iter;
     gboolean	valid = FALSE,
@@ -1336,8 +1344,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
         combination_vbox = gtk_vbox_new(FALSE, 0);
 	/* get current time */  
         current_time = time(NULL);
-        utc_time = mktime(gmtime(&current_time));
-        diff_time = utc_time - current_time + 60 * 60 * atol(item_value(wcs.day_data[0], "station_time_zone"));
+	diff_time = calculate_diff_time(atol(item_value(wcs.day_data[0], "station_time_zone")));
         current_time += diff_time;
 	
         if(!wcs.current_data_is_invalid){
