@@ -562,8 +562,13 @@ void weather_window_add_custom_station(void){
     gtk_entry_set_max_length((GtkEntry*)custom_station_code, 9);
     gtk_entry_set_width_chars((GtkEntry*)custom_station_code, 9);
 /* enable help for this window */
-    ossohelp_dialog_help_enable(GTK_DIALOG(window_add_custom_station), 
+    #ifdef HILDON
+	hildon_help_dialog_help_enable(GTK_DIALOG(window_add_custom_station), 
 			    OMWEATHER_ADD_CUSTOM_STATION_HELP_ID, app->osso);
+    #else    
+	ossohelp_dialog_help_enable(GTK_DIALOG(window_add_custom_station), 
+			    OMWEATHER_ADD_CUSTOM_STATION_HELP_ID, app->osso);
+    #endif
     gtk_widget_show_all(window_add_custom_station);
     gtk_widget_set_size_request(GTK_WIDGET(custom_station_name), 230, -1);
     gtk_widget_set_size_request(GTK_WIDGET(custom_station_code), 230, -1);
@@ -663,8 +668,13 @@ void weather_window_add_station(GtkWidget *widget, GdkEvent *event,
             		G_CALLBACK (changed_stations), NULL);
     
     /* enable help for this window */
-    ossohelp_dialog_help_enable(GTK_DIALOG(window_add_station), 
+    #ifdef HILDON
+	hildon_help_dialog_help_enable(GTK_DIALOG(window_add_station), 
 				OMWEATHER_ADD_STATION_HELP_ID, app->osso);
+    #else    
+	ossohelp_dialog_help_enable(GTK_DIALOG(window_add_station), 
+				OMWEATHER_ADD_STATION_HELP_ID, app->osso);
+    #endif
     /* run dialog */
     switch(gtk_dialog_run(GTK_DIALOG(window_add_station))){
 	default:
@@ -729,6 +739,7 @@ void weather_window_settings(GtkWidget *widget,	GdkEvent *event,
     GtkIconInfo *gtkicon_arrow;
 #endif
     gboolean	valid = FALSE;
+    gboolean    result_help = FALSE;
     GtkTreeIter	iter;
     char	flag_update_icon = '\0'; /* Flag update main weather icon of desktop */
 #ifndef RELEASE
@@ -1206,9 +1217,14 @@ void weather_window_settings(GtkWidget *widget,	GdkEvent *event,
 						    GTK_JUSTIFY_LEFT),
         			label = gtk_label_new(_("Events")));
 #endif
-/* enable help for this window */
-    ossohelp_dialog_help_enable(GTK_DIALOG(window_config), OMWEATHER_SETTINGS_HELP_ID, app->osso);
 
+/* enable help for this window */
+    #ifdef HILDON
+	result_help = hildon_help_dialog_help_enable(GTK_DIALOG(window_config), OMWEATHER_SETTINGS_HELP_ID, app->osso);
+    #else    
+	result_help = ossohelp_dialog_help_enable(GTK_DIALOG(window_config), OMWEATHER_SETTINGS_HELP_ID, app->osso);
+    #endif
+    
     gtk_widget_show_all(window_config);
     gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), app->config->current_settings_page);
     highlight_current_station(GTK_TREE_VIEW(station_list_view));
@@ -1466,6 +1482,7 @@ void create_about_dialog(void){
 /* Create Notebook widget */
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(help_dialog)->vbox),
         	    notebook = gtk_notebook_new(), TRUE, TRUE, 0);
+
 /* About tab */
     snprintf(tmp_buff, sizeof(tmp_buff),
 #ifdef DISPLAY_BUILD
@@ -1492,6 +1509,7 @@ void create_about_dialog(void){
         			create_scrolled_window_with_text(tmp_buff,
 						    GTK_JUSTIFY_CENTER),
 				title = gtk_label_new(_("About")));
+
 /* Authors tab */
     snprintf(tmp_buff, sizeof(tmp_buff), "%s",
 		_("\nAuthor and maintenance:\n"
@@ -1503,6 +1521,7 @@ void create_about_dialog(void){
         			create_scrolled_window_with_text(tmp_buff,
 						    GTK_JUSTIFY_LEFT),
 				title = gtk_label_new(_("Authors")));
+
 /* Thanks tab */
     snprintf(tmp_buff, sizeof(tmp_buff), "%s",
 	    _("\nEd Bartosh - for more feature requests,\n"
@@ -1545,7 +1564,11 @@ void create_about_dialog(void){
 						    GTK_JUSTIFY_LEFT),
         			title = gtk_label_new(_("Translators")));
 /* enable help for this window */
+#ifdef HILDON
+    hildon_help_dialog_help_enable(GTK_DIALOG(help_dialog), OMWEATHER_ABOUT_HELP_ID, app->osso);
+#else    
     ossohelp_dialog_help_enable(GTK_DIALOG(help_dialog), OMWEATHER_ABOUT_HELP_ID, app->osso);
+#endif
     gtk_widget_show_all(help_dialog);
 /* start dialog window */
     result = gtk_dialog_run(GTK_DIALOG(help_dialog));
